@@ -1,5 +1,9 @@
 import hmac
 import logging
+try:
+    import pkg_resources
+except ImportError:
+    pkg_resources = None
 import sys
 import uuid
 from pprint import pformat
@@ -94,7 +98,11 @@ def transform(value, stack=[], context=None):
     if any(value is s for s in stack):
         ret = 'cycle'
     elif isinstance(value, (tuple, list, set, frozenset)):
-        ret = type(value)(transform_rec(o) for o in value)
+        try:
+            ret = type(value)(transform_rec(o) for o in value)
+        except TypeError, te:
+            # We may be dealing with a namedtuple
+            ret = type(value)(transform_rec(o) for o in value[:])
     elif isinstance(value, uuid.UUID):
         ret = repr(value)
     elif isinstance(value, dict):
@@ -235,8 +243,18 @@ def get_versions(module_list=None):
             version = app.VERSION
         elif hasattr(app, '__version__'):
             version = app.__version__
+        elif pkg_resources:
+            # pull version from pkg_resources if distro exists
+            try:
+                version = pkg_resources.get_distribution(module_name).version
+            except pkg_resources.DistributionNotFound:
+                continue
         else:
             continue
+
+        if not version:
+            continue
+
         if isinstance(version, (list, tuple)):
             version = '.'.join(str(o) for o in version)
         versions[module_name] = version
